==> smartgwtee-eval-5.0p.zip: com/smartgwt/logicalstructure/widgets/RichTextEditorLogicalStructure.java <==
package com.smartgwt.logicalstructure.widgets;
import com.smartgwt.client.core.*;
import com.smartgwt.client.rpc.*;
import com.smartgwt.client.i18n.*;
import com.smartgwt.client.event.*;
import com.smartgwt.client.util.*;
import com.smartgwt.client.util.workflow.*;
import com.smartgwt.client.types.*;
import com.smartgwt.client.data.*;
import com.smartgwt.client.data.fields.*;
import com.smartgwt.client.tools.*;
import com.smartgwt.client.widgets.*;
import com.smartgwt.client.widgets.calendar.*;
import com.smartgwt.client.widgets.chart.*;
import com.smartgwt.client.widgets.cube.*;
import com.smartgwt.client.widgets.drawing.*;
import com.smartgwt.client.widgets.form.*;
import com.smartgwt.client.widgets.form.fields.*;
import com.smartgwt.client.widgets.form.validator.*;
import com.smartgwt.client.widgets.grid.*;
import com.smartgwt.client.widgets.layout.*;
import com.smartgwt.client.widgets.menu.*;
import com.smartgwt.client.widgets.plugins.*;
import com.smartgwt.client.widgets.tab.*;
import com.smartgwt.client.widgets.tableview.*;
import com.smartgwt.client.widgets.tile.*;
import com.smartgwt.client.widgets.toolbar.*;
import com.smartgwt.client.widgets.tree.*;
import com.smartgwt.client.widgets.viewer.*;
import com.smartgwt.logicalstructure.core.*;
import com.smartgwt.logicalstructure.widgets.*;
import com.smartgwt.logicalstructure.widgets.form.*;
import com.smartgwt.logicalstructure.widgets.tile.*;
import com.smartgwt.logicalstructure.widgets.grid.*;
import com.smartgwt.logicalstructure.widgets.chart.*;
import com.smartgwt.logicalstructure.widgets.layout.*;
import com.smartgwt.logicalstructure.widgets.menu.*;
import com.smartgwt.logicalstructure.widgets.tab.*;
import com.smartgwt.logicalstructure.widgets.toolbar.*;
import com.smartgwt.logicalstructure.widgets.tree.*;
import com.smartgwt.logicalstructure.widgets.viewer.*;
import com.smartgwt.logicalstructure.widgets.calendar.*;
import com.smartgwt.logicalstructure.widgets.cube.*;
import com.smartgwt.logicalstructure.widgets.drawing.*;

public class RichTextEditorLogicalStructure extends VLayoutLogicalStructure {
    public String alignCenterPrompt;
    public String alignLeftPrompt;
    public String alignRightPrompt;
    public String backgroundColorPrompt;
    public String boldSelectionPrompt;
    public String colorPrompt;
    public String copySelectionPrompt;
    public String cutSelectionPrompt;
    public String editAreaBackgroundColor;
    public String fontSelectorPrompt;
    public String fontSizeSelectorPrompt;
    public String indentPrompt;
    public String italicSelectionPrompt;
    public String justifyPrompt;
    public String linkPrompt;
    public String linkUrlTitle;
    public String listPropertiesPrompt;
    public String listPropertiesWarningText;
    public String moveFocusOnTab;
    public String orderedListPrompt;
    public String outdentPrompt;
    public String pasteSelectionPrompt;
    public String strikethroughSelectionPrompt;
    public String toolbarBackgroundColor;
    public String underlineSelectionPrompt;
    public String unorderedListPrompt;
    public String value;
}

==> smartgwtee-eval-12.0p.zip: com/smartgwt/logicalstructure/widgets/RichTextEditorLogicalStructure.java <==
package com.smartgwt.logicalstructure.widgets;
import com.smartgwt.client.core.*;
import com.smartgwt.client.rpc.*;
import com.smartgwt.client.i18n.*;
import com.smartgwt.client.event.*;
import com.smartgwt.client.util.*;
import com.smartgwt.client.util.workflow.*;
import com.smartgwt.client.types.*;
import com.smartgwt.client.data.*;
import com.smartgwt.client.data.fields.*;
import com.smartgwt.client.tools.*;
import com.smartgwt.client.widgets.*;
import com.smartgwt.client.widgets.calendar.*;
import com.smartgwt.client.widgets.chart.*;
import com.smartgwt.client.widgets.cube.*;
import com.smartgwt.client.widgets.drawing.*;
import com.smartgwt.client.widgets.form.*;
import com.smartgwt.client.widgets.form.fields.*;
import com.smartgwt.client.widgets.form.validator.*;
import com.smartgwt.client.widgets.grid.*;
import com.smartgwt.client.widgets.layout.*;
import com.smartgwt.client.widgets.menu.*;
import com.smartgwt.client.widgets.plugins.*;
import com.smartgwt.client.widgets.tab.*;
import com.smartgwt.client.widgets.tableview.*;
import com.smartgwt.client.widgets.tile.*;
import com.smartgwt.client.widgets.toolbar.*;
import com.smartgwt.client.widgets.tree.*;
import com.smartgwt.client.widgets.viewer.*;
import com.smartgwt.logicalstructure.core.*;
import com.smartgwt.logicalstructure.widgets.*;
import com.smartgwt.logicalstructure.widgets.form.*;
import com.smartgwt.logicalstructure.widgets.tile.*;
import com.smartgwt.logicalstructure.widgets.grid.*;
import com.smartgwt.logicalstructure.widgets.chart.*;
import com.smartgwt.logicalstructure.widgets.layout.*;
import com.smartgwt.logicalstructure.widgets.menu.*;
import com.smartgwt.logicalstructure.widgets.tab.*;
import com.smartgwt.logicalstructure.widgets.toolbar.*;
import com.smartgwt.logicalstructure.widgets.tree.*;
import com.smartgwt.logicalstructure.widgets.viewer.*;
import com.smartgwt.logicalstructure.widgets.calendar.*;
import com.smartgwt.logicalstructure.widgets.cube.*;
import com.smartgwt.logicalstructure.widgets.drawing.*;

public class RichTextEditorLogicalStructure extends VLayoutLogicalStructure {
    public String alignCenterPrompt;
    public String alignLeftPrompt;
    public String alignRightPrompt;
    public String backgroundColorPrompt;
    public String boldSelectionPrompt;
    public String colorPrompt;
    public String copySelectionPrompt;
    public String cutSelectionPrompt;
    public String editAreaBackgroundColor;
    public String fontSelectorPrompt;
    public String fontSizeSelectorPrompt;
    public String indentPrompt;
    public String italicSelectionPrompt;
    public String justifyPrompt;
    public String listPropertiesPrompt;
    public String listPropertiesWarningText;
    public String moveFocusOnTab;
    public String orderedListPrompt;
    public String outdentPrompt;
    public String pasteSelectionPrompt;
    public String strikethroughSelectionPrompt;
    public String styleWithCSS;
    public String toolbarBackgroundColor;
    public String underlineSelectionPrompt;
    public String unorderedListPrompt;
    public String useDesignMode;
    public String value;
}
